@@ -131,7 +131,7 @@ static PyObject *PylibMC_ErrFromMemcached(PylibMC_Client *, const char *,
 static PyObject *_PylibMC_Unpickle(const char *, size_t);
 static PyObject *_PylibMC_Pickle(PyObject *);
 static int _PylibMC_CheckKey(PyObject *);
-static int _PylibMC_CheckKeyStringAndSize(char *, size_t);
+static int _PylibMC_CheckKeyStringAndSize(char *, int);
 /* }}} */
 
 /* {{{ Type's method table */
@@ -164,7 +164,7 @@ static PyMethodDef PylibMC_ClientType_methods[] = {
         "Get behaviors dict."},
     {"set_behaviors", (PyCFunction)PylibMC_Client_set_behaviors, METH_O,
         "Set behaviors dict."},
-    {NULL}
+    {NULL, NULL, 0, NULL}
 };
 /* }}} */
 
@@ -219,6 +219,7 @@ static PyTypeObject PylibMC_ClientType = {
     0,          
     0,          
     0,          
+    0
 };
 
 /* }}} */
