@@ -68,9 +68,21 @@ True
 
 Now for keys with funny types.
 >>> c.set(1, "hi")
-True
+Traceback (most recent call last):
+  ...
+TypeError: argument 1 must be string or read-only buffer, not int
 >>> c.get(1)
-'hi'
+Traceback (most recent call last):
+  ...
+TypeError: key must be an instance of str
+>>> c.set_multi({1: True})
+Traceback (most recent call last):
+  ...
+TypeError: key must be an instance of str
+>>> c.get_multi([1, 2])
+Traceback (most recent call last):
+  ...
+TypeError: key must be an instance of str
 """
 
 import _pylibmc
